import { Assertion, Characters } from "./builder";
var CharactersMap = {
    ANY: ".",
    DIGIT: "\\d",
    NON_DIGIT: "\\D",
    ALPHANUM: "\\w",
    NON_ALPHANUM: "\\W",
    SPACE: "\\s",
    NON_SPACE: "\\S",
    HTAB: "\\t",
    VTAB: "\\v",
    RETURN: "\\r",
    LINEFEED: "\\n",
    FORMFEED: "\\f",
    BACKSPACE: "[\\b]",
    NULL: "(?:\\0)"
};
export var ParseMatch = function (character) {
    if (typeof (character) === "number" && character in Characters) {
        return CharactersMap[Characters[character]];
    }
    if (typeof (character) === "string") {
        return EscapeCharacter(character);
    }
    if (typeof (character) === "object" && isLiteralCharacterInterface(character)) {
        return character.character;
    }
    throw new Error("Invalid input for match: " + character);
};
var isLiteralCharacterInterface = function (object) {
    return "character" in object;
};
var EscapeCharacter = function (character) {
    return character.replace(/[-[\]{}()*+?.,\\\/^$|#]/g, '\\$&');
};
export var ParseAssertion = function (assertion) {
    if (typeof (assertion) === "number" && assertion in Assertion) {
        return AssertionMap[Assertion[assertion]];
    }
    throw new Error("Invalid input for assertion: " + assertion);
};
var AssertionMap = {
    START: "^",
    END: "$",
    WORD_BOUNDARY: "\\b",
    NOT_WORD_BOUNDARY: "\\B"
};
//# sourceMappingURL=builderHelpers.js.map